@@ -1,7 +1,7 @@
 package ExtUtils::MakeMaker::Dump;
 
 our $DATE = '2015-01-14'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010;
 use strict;
@@ -59,6 +59,7 @@ sub dump_makefile_pl_script {
     my $tag = UUID::Random::generate();
     my @cmd = (
         $^X, (map {"-I$_"} @$libs),
+        "-MTimeout::Self=3", # to defeat scripts that prompts for stuffs
         "-MExtUtils::MakeMaker::Patch::DumpAndExit=-tag,$tag",
         $filename,
         "--version",
@@ -101,15 +102,16 @@ ExtUtils::MakeMaker::Dump - Run a Makefile.PL script but only to dump the %Write
 
 =head1 VERSION
 
-This document describes version 0.02 of ExtUtils::MakeMaker::Dump (from Perl distribution ExtUtils-MakeMaker-Dump), released on 2015-01-14.
+This document describes version 0.03 of ExtUtils::MakeMaker::Dump (from Perl distribution ExtUtils-MakeMaker-Dump), released on 2015-01-14.
 
 =head1 FUNCTIONS
 
 
 =head2 dump_makefile_pl_script(%args) -> [status, msg, result, meta]
 
-Run a Makefile.PL script but only to dump the %WriteMakefileArgs.
+{en_US Run a Makefile.PL script but only to dump the %WriteMakefileArgs}.
 
+{en_US 
 This function runs C<Makefile.PL> script that uses C<ExtUtils::MakeMaker> but
 monkey-patches beforehand so that C<WriteMakefile()> will dump the argument and
 then exit. The goal is to get the argument without actually running the script
@@ -123,6 +125,7 @@ the patch. (Another alternative would be to do a static analysis of the script.)
 
 Note: C<Makefile.PL> using C<Module::Install> works too, because under the hood
 it's still C<ExtUtils::MakeMaker>.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -130,11 +133,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<filename>* => I<str>
 
-Path to the script.
+{en_US Path to the script}.
 
 =item * B<libs> => I<array[str]>
 
-Libraries to unshift to @INC when running script.
+{en_US Libraries to unshift to @INC when running script}.
 
 =back
 
